@@ -104,7 +104,7 @@ class S3Hook(AwsBaseHook):
     """
 
     conn_type = 's3'
-    hook_name = 'S3'
+    hook_name = 'Amazon S3'
 
     def __init__(self, *args, **kwargs) -> None:
         kwargs['client_type'] = 's3'
@@ -132,7 +132,6 @@ class S3Hook(AwsBaseHook):
         Parses the S3 Url into a bucket name and key.
 
         :param s3url: The S3 Url to parse.
-        :rtype s3url: str
         :return: the parsed bucket name and key
         :rtype: tuple of str
         """
@@ -152,7 +151,6 @@ class S3Hook(AwsBaseHook):
         Check if bucket_name exists.
 
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         :return: True if it exists and False if not.
         :rtype: bool
         """
@@ -164,12 +162,11 @@ class S3Hook(AwsBaseHook):
             return False
 
     @provide_bucket_name
-    def get_bucket(self, bucket_name: Optional[str] = None) -> str:
+    def get_bucket(self, bucket_name: Optional[str] = None) -> object:
         """
         Returns a boto3.S3.Bucket object
 
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         :return: the bucket object to the bucket name.
         :rtype: boto3.S3.Bucket
         """
@@ -190,9 +187,7 @@ class S3Hook(AwsBaseHook):
         Creates an Amazon S3 bucket.
 
         :param bucket_name: The name of the bucket
-        :type bucket_name: str
         :param region_name: The name of the aws region in which to create the bucket.
-        :type region_name: str
         """
         if not region_name:
             region_name = self.get_conn().meta.region_name
@@ -209,11 +204,8 @@ class S3Hook(AwsBaseHook):
         Checks that a prefix exists in a bucket
 
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         :param prefix: a key prefix
-        :type prefix: str
         :param delimiter: the delimiter marks key hierarchy.
-        :type delimiter: str
         :return: False if the prefix does not exist in the bucket and True if it does.
         :rtype: bool
         """
@@ -236,15 +228,10 @@ class S3Hook(AwsBaseHook):
         Lists prefixes in a bucket under prefix
 
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         :param prefix: a key prefix
-        :type prefix: str
         :param delimiter: the delimiter marks key hierarchy.
-        :type delimiter: str
         :param page_size: pagination size
-        :type page_size: int
         :param max_items: maximum items to return
-        :type max_items: int
         :return: a list of matched prefixes
         :rtype: list
         """
@@ -281,15 +268,10 @@ class S3Hook(AwsBaseHook):
         Lists keys in a bucket under prefix and not containing delimiter
 
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         :param prefix: a key prefix
-        :type prefix: str
         :param delimiter: the delimiter marks key hierarchy.
-        :type delimiter: str
         :param page_size: pagination size
-        :type page_size: int
         :param max_items: maximum items to return
-        :type max_items: int
         :return: a list of matched keys
         :rtype: list
         """
@@ -320,9 +302,7 @@ class S3Hook(AwsBaseHook):
         Checks if a key exists in a bucket
 
         :param key: S3 key that will point to the file
-        :type key: str
         :param bucket_name: Name of the bucket in which the file is stored
-        :type bucket_name: str
         :return: True if the key exists and False if not.
         :rtype: bool
         """
@@ -342,9 +322,7 @@ class S3Hook(AwsBaseHook):
         Returns a boto3.s3.Object
 
         :param key: the path to the key
-        :type key: str
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         :return: the key object from the bucket
         :rtype: boto3.s3.Object
         """
@@ -368,9 +346,7 @@ class S3Hook(AwsBaseHook):
         Reads a key from S3
 
         :param key: S3 key that will point to the file
-        :type key: str
         :param bucket_name: Name of the bucket in which the file is stored
-        :type bucket_name: str
         :return: the content of the key
         :rtype: str
         """
@@ -392,17 +368,11 @@ class S3Hook(AwsBaseHook):
         Reads a key with S3 Select.
 
         :param key: S3 key that will point to the file
-        :type key: str
         :param bucket_name: Name of the bucket in which the file is stored
-        :type bucket_name: str
         :param expression: S3 Select expression
-        :type expression: str
         :param expression_type: S3 Select expression type
-        :type expression_type: str
         :param input_serialization: S3 Select input data serialization format
-        :type input_serialization: dict
         :param output_serialization: S3 Select output data serialization format
-        :type output_serialization: dict
         :return: retrieved subset of original data by S3 Select
         :rtype: str
 
@@ -440,11 +410,8 @@ class S3Hook(AwsBaseHook):
         Checks that a key matching a wildcard expression exists in a bucket
 
         :param wildcard_key: the path to the key
-        :type wildcard_key: str
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         :param delimiter: the delimiter marks key hierarchy
-        :type delimiter: str
         :return: True if a key exists and False if not.
         :rtype: bool
         """
@@ -462,11 +429,8 @@ class S3Hook(AwsBaseHook):
         Returns a boto3.s3.Object object matching the wildcard expression
 
         :param wildcard_key: the path to the key
-        :type wildcard_key: str
         :param bucket_name: the name of the bucket
-        :type bucket_name: str
         :param delimiter: the delimiter marks key hierarchy
-        :type delimiter: str
         :return: the key object from the bucket or None if none has been found.
         :rtype: boto3.s3.Object
         """
@@ -493,23 +457,16 @@ class S3Hook(AwsBaseHook):
         Loads a local file to S3
 
         :param filename: path to the file to load.
-        :type filename: Union[Path, str]
         :param key: S3 key that will point to the file
-        :type key: str
         :param bucket_name: Name of the bucket in which to store the file
-        :type bucket_name: str
         :param replace: A flag to decide whether or not to overwrite the key
             if it already exists. If replace is False and the key exists, an
             error will be raised.
-        :type replace: bool
         :param encrypt: If True, the file will be encrypted on the server-side
             by S3 and will be stored in an encrypted form while at rest in S3.
-        :type encrypt: bool
         :param gzip: If True, the file will be compressed locally
-        :type gzip: bool
         :param acl_policy: String specifying the canned ACL policy for the file being
             uploaded to the S3 bucket.
-        :type acl_policy: str
         """
         filename = str(filename)
         if not replace and self.check_for_key(key, bucket_name):
@@ -550,24 +507,16 @@ class S3Hook(AwsBaseHook):
         boto infrastructure to ship a file to s3.
 
         :param string_data: str to set as content for the key.
-        :type string_data: str
         :param key: S3 key that will point to the file
-        :type key: str
         :param bucket_name: Name of the bucket in which to store the file
-        :type bucket_name: str
         :param replace: A flag to decide whether or not to overwrite the key
             if it already exists
-        :type replace: bool
         :param encrypt: If True, the file will be encrypted on the server-side
             by S3 and will be stored in an encrypted form while at rest in S3.
-        :type encrypt: bool
         :param encoding: The string to byte encoding
-        :type encoding: str
         :param acl_policy: The string to specify the canned ACL policy for the
             object to be uploaded
-        :type acl_policy: str
         :param compression: Type of compression to use, currently only gzip is supported.
-        :type compression: str
         """
         encoding = encoding or 'utf-8'
 
@@ -606,20 +555,14 @@ class S3Hook(AwsBaseHook):
         boto infrastructure to ship a file to s3.
 
         :param bytes_data: bytes to set as content for the key.
-        :type bytes_data: bytes
         :param key: S3 key that will point to the file
-        :type key: str
         :param bucket_name: Name of the bucket in which to store the file
-        :type bucket_name: str
         :param replace: A flag to decide whether or not to overwrite the key
             if it already exists
-        :type replace: bool
         :param encrypt: If True, the file will be encrypted on the server-side
             by S3 and will be stored in an encrypted form while at rest in S3.
-        :type encrypt: bool
         :param acl_policy: The string to specify the canned ACL policy for the
             object to be uploaded
-        :type acl_policy: str
         """
         file_obj = io.BytesIO(bytes_data)
         self._upload_file_obj(file_obj, key, bucket_name, replace, encrypt, acl_policy)
@@ -640,20 +583,14 @@ class S3Hook(AwsBaseHook):
         Loads a file object to S3
 
         :param file_obj: The file-like object to set as the content for the S3 key.
-        :type file_obj: file-like object
         :param key: S3 key that will point to the file
-        :type key: str
         :param bucket_name: Name of the bucket in which to store the file
-        :type bucket_name: str
         :param replace: A flag that indicates whether to overwrite the key
             if it already exists.
-        :type replace: bool
         :param encrypt: If True, S3 encrypts the file on the server,
             and the file is stored in encrypted form at rest in S3.
-        :type encrypt: bool
         :param acl_policy: The string to specify the canned ACL policy for the
             object to be uploaded
-        :type acl_policy: str
         """
         self._upload_file_obj(file_obj, key, bucket_name, replace, encrypt, acl_policy)
 
@@ -704,25 +641,19 @@ class S3Hook(AwsBaseHook):
             It can be either full s3:// style url or relative path from root level.
 
             When it's specified as a full s3:// url, please omit source_bucket_name.
-        :type source_bucket_key: str
         :param dest_bucket_key: The key of the object to copy to.
 
             The convention to specify `dest_bucket_key` is the same
             as `source_bucket_key`.
-        :type dest_bucket_key: str
         :param source_bucket_name: Name of the S3 bucket where the source object is in.
 
             It should be omitted when `source_bucket_key` is provided as a full s3:// url.
-        :type source_bucket_name: str
         :param dest_bucket_name: Name of the S3 bucket to where the object is copied.
 
             It should be omitted when `dest_bucket_key` is provided as a full s3:// url.
-        :type dest_bucket_name: str
         :param source_version_id: Version ID of the source object (OPTIONAL)
-        :type source_version_id: str
         :param acl_policy: The string to specify the canned ACL policy for the
             object to be copied which is private by default.
-        :type acl_policy: str
         """
         acl_policy = acl_policy or 'private'
 
@@ -760,9 +691,7 @@ class S3Hook(AwsBaseHook):
         To delete s3 bucket, delete all s3 bucket objects and then delete the bucket.
 
         :param bucket_name: Bucket name
-        :type bucket_name: str
         :param force_delete: Enable this to delete bucket even if not empty
-        :type force_delete: bool
         :return: None
         :rtype: None
         """
@@ -777,7 +706,6 @@ class S3Hook(AwsBaseHook):
         Delete keys from the bucket.
 
         :param bucket: Name of the bucket in which you are going to delete object(s)
-        :type bucket: str
         :param keys: The key(s) to delete from S3 bucket.
 
             When ``keys`` is a string, it's supposed to be the key name of
@@ -785,7 +713,6 @@ class S3Hook(AwsBaseHook):
 
             When ``keys`` is a list, it's supposed to be the list of the
             keys to delete.
-        :type keys: str or list
         """
         if isinstance(keys, str):
             keys = [keys]
@@ -812,12 +739,9 @@ class S3Hook(AwsBaseHook):
         Downloads a file from the S3 location to the local file system.
 
         :param key: The key path in S3.
-        :type key: str
         :param bucket_name: The specific bucket to use.
-        :type bucket_name: Optional[str]
         :param local_path: The local path to the downloaded file. If no path is provided it will use the
             system's temporary directory.
-        :type local_path: Optional[str]
         :return: the file name.
         :rtype: str
         """
@@ -849,15 +773,11 @@ class S3Hook(AwsBaseHook):
         Generate a presigned url given a client, its method, and arguments
 
         :param client_method: The client method to presign for.
-        :type client_method: str
         :param params: The parameters normally passed to ClientMethod.
-        :type params: dict
         :param expires_in: The number of seconds the presigned url is valid for.
             By default it expires in an hour (3600 seconds).
-        :type expires_in: int
         :param http_method: The http method to use on the generated url.
             By default, the http method is whatever is used in the method's model.
-        :type http_method: str
         :return: The presigned url.
         :rtype: str
         """
@@ -877,7 +797,6 @@ class S3Hook(AwsBaseHook):
         Gets a List of tags from a bucket.
 
         :param bucket_name: The name of the bucket.
-        :type bucket_name: str
         :return: A List containing the key/value pairs for the tags
         :rtype: Optional[List[Dict[str, str]]]
         """
@@ -902,13 +821,9 @@ class S3Hook(AwsBaseHook):
         Overwrites the existing TagSet with provided tags.  Must provide either a TagSet or a key/value pair.
 
         :param tag_set: A List containing the key/value pairs for the tags.
-        :type tag_set: List[Dict[str, str]]
         :param key: The Key for the new TagSet entry.
-        :type key: str
         :param value: The Value for the new TagSet entry.
-        :type value: str
         :param bucket_name: The name of the bucket.
-        :type bucket_name: str
         :return: None
         :rtype: None
         """
@@ -935,7 +850,6 @@ class S3Hook(AwsBaseHook):
         Deletes all tags from a bucket.
 
         :param bucket_name: The name of the bucket.
-        :type bucket_name: str
         :return: None
         :rtype: None
         """
