@@ -21,8 +21,9 @@ import tarfile
 import tempfile
 import time
 import warnings
+from datetime import datetime
 from functools import partial
-from typing import Any, Callable, Dict, Generator, List, Optional, Set
+from typing import Any, Callable, Dict, Generator, List, Optional, Set, cast
 
 from botocore.exceptions import ClientError
 
@@ -68,9 +69,7 @@ def secondary_training_status_changed(current_job_description: dict, prev_job_de
     Returns true if training job's secondary status message has changed.
 
     :param current_job_description: Current job description, returned from DescribeTrainingJob call.
-    :type current_job_description: dict
     :param prev_job_description: Previous job description, returned from DescribeTrainingJob call.
-    :type prev_job_description: dict
 
     :return: Whether the secondary status message of a training job changed or not.
     """
@@ -95,15 +94,13 @@ def secondary_training_status_changed(current_job_description: dict, prev_job_de
 
 
 def secondary_training_status_message(
-    job_description: Dict[str, List[dict]], prev_description: Optional[dict]
+    job_description: Dict[str, List[Any]], prev_description: Optional[dict]
 ) -> str:
     """
     Returns a string contains start time and the secondary training job status message.
 
     :param job_description: Returned response from DescribeTrainingJob call
-    :type job_description: dict
     :param prev_description: Previous job description from DescribeTrainingJob call
-    :type prev_description: dict
 
     :return: Job status string to be printed.
     """
@@ -125,7 +122,9 @@ def secondary_training_status_message(
     status_strs = []
     for transition in transitions_to_print:
         message = transition['StatusMessage']
-        time_str = timezone.convert_to_utc(job_description['LastModifiedTime']).strftime('%Y-%m-%d %H:%M:%S')
+        time_str = timezone.convert_to_utc(cast(datetime, job_description['LastModifiedTime'])).strftime(
+            '%Y-%m-%d %H:%M:%S'
+        )
         status_strs.append(f"{time_str} {transition['Status']} - {message}")
 
     return '\n'.join(status_strs)
@@ -156,11 +155,8 @@ class SageMakerHook(AwsBaseHook):
         Tar the local file or directory and upload to s3
 
         :param path: local file or directory
-        :type path: str
         :param key: s3 key
-        :type key: str
         :param bucket: s3 bucket
-        :type bucket: str
         :return: None
         """
         with tempfile.TemporaryFile() as temp_file:
@@ -179,7 +175,6 @@ class SageMakerHook(AwsBaseHook):
         Extract the S3 operations from the configuration and execute them.
 
         :param config: config of SageMaker operation
-        :type config: dict
         :rtype: dict
         """
         s3_operations = config.pop('S3Operations', None)
@@ -200,7 +195,6 @@ class SageMakerHook(AwsBaseHook):
         Check if an S3 URL exists
 
         :param s3url: S3 url
-        :type s3url: str
         :rtype: bool
         """
         bucket, key = S3Hook.parse_s3_url(s3url)
@@ -224,7 +218,6 @@ class SageMakerHook(AwsBaseHook):
         Check if a training configuration is valid
 
         :param training_config: training_config
-        :type training_config: dict
         :return: None
         """
         if "InputDataConfig" in training_config:
@@ -237,7 +230,6 @@ class SageMakerHook(AwsBaseHook):
         Check if a tuning configuration is valid
 
         :param tuning_config: tuning_config
-        :type tuning_config: dict
         :return: None
         """
         for channel in tuning_config['TrainingJobDefinition']['InputDataConfig']:
@@ -280,13 +272,10 @@ class SageMakerHook(AwsBaseHook):
         interleaving the events from each stream so they're yielded in timestamp order.
 
         :param log_group: The name of the log group.
-        :type log_group: str
         :param streams: A list of the log stream names. The position of the stream in this list is
             the stream number.
-        :type streams: list
         :param positions: A list of pairs of (timestamp, skip) which represents the last record
             read from each stream.
-        :type positions: list
         :return: A tuple of (stream number, cloudwatch log event).
         """
         positions = positions or {s: Position(timestamp=0, skip=0) for s in streams}
@@ -324,16 +313,12 @@ class SageMakerHook(AwsBaseHook):
         Create a training job
 
         :param config: the config for training
-        :type config: dict
         :param wait_for_completion: if the program should keep running until job finishes
-        :type wait_for_completion: bool
         :param check_interval: the time interval in seconds which the operator
             will check the status of any SageMaker job
-        :type check_interval: int
         :param max_ingestion_time: the maximum ingestion time in seconds. Any
             SageMaker jobs that run longer than this will fail. Setting this to
             None implies no timeout for any SageMaker job.
-        :type max_ingestion_time: int
         :return: A response to training job creation
         """
         self.check_training_config(config)
@@ -375,16 +360,12 @@ class SageMakerHook(AwsBaseHook):
         Create a tuning job
 
         :param config: the config for tuning
-        :type config: dict
         :param wait_for_completion: if the program should keep running until job finishes
-        :type wait_for_completion: bool
         :param check_interval: the time interval in seconds which the operator
             will check the status of any SageMaker job
-        :type check_interval: int
         :param max_ingestion_time: the maximum ingestion time in seconds. Any
             SageMaker jobs that run longer than this will fail. Setting this to
             None implies no timeout for any SageMaker job.
-        :type max_ingestion_time: int
         :return: A response to tuning job creation
         """
         self.check_tuning_config(config)
@@ -411,16 +392,12 @@ class SageMakerHook(AwsBaseHook):
         Create a transform job
 
         :param config: the config for transform job
-        :type config: dict
         :param wait_for_completion: if the program should keep running until job finishes
-        :type wait_for_completion: bool
         :param check_interval: the time interval in seconds which the operator
             will check the status of any SageMaker job
-        :type check_interval: int
         :param max_ingestion_time: the maximum ingestion time in seconds. Any
             SageMaker jobs that run longer than this will fail. Setting this to
             None implies no timeout for any SageMaker job.
-        :type max_ingestion_time: int
         :return: A response to transform job creation
         """
         if "S3DataSource" in config['TransformInput']['DataSource']:
@@ -448,16 +425,12 @@ class SageMakerHook(AwsBaseHook):
         Create a processing job
 
         :param config: the config for processing job
-        :type config: dict
         :param wait_for_completion: if the program should keep running until job finishes
-        :type wait_for_completion: bool
         :param check_interval: the time interval in seconds which the operator
             will check the status of any SageMaker job
-        :type check_interval: int
         :param max_ingestion_time: the maximum ingestion time in seconds. Any
             SageMaker jobs that run longer than this will fail. Setting this to
             None implies no timeout for any SageMaker job.
-        :type max_ingestion_time: int
         :return: A response to transform job creation
         """
         response = self.get_conn().create_processing_job(**config)
@@ -476,7 +449,6 @@ class SageMakerHook(AwsBaseHook):
         Create a model job
 
         :param config: the config for model
-        :type config: dict
         :return: A response to model creation
         """
         return self.get_conn().create_model(**config)
@@ -486,7 +458,6 @@ class SageMakerHook(AwsBaseHook):
         Create an endpoint config
 
         :param config: the config for endpoint-config
-        :type config: dict
         :return: A response to endpoint config creation
         """
         return self.get_conn().create_endpoint_config(**config)
@@ -502,16 +473,12 @@ class SageMakerHook(AwsBaseHook):
         Create an endpoint
 
         :param config: the config for endpoint
-        :type config: dict
         :param wait_for_completion: if the program should keep running until job finishes
-        :type wait_for_completion: bool
         :param check_interval: the time interval in seconds which the operator
             will check the status of any SageMaker job
-        :type check_interval: int
         :param max_ingestion_time: the maximum ingestion time in seconds. Any
             SageMaker jobs that run longer than this will fail. Setting this to
             None implies no timeout for any SageMaker job.
-        :type max_ingestion_time: int
         :return: A response to endpoint creation
         """
         response = self.get_conn().create_endpoint(**config)
@@ -537,16 +504,12 @@ class SageMakerHook(AwsBaseHook):
         Update an endpoint
 
         :param config: the config for endpoint
-        :type config: dict
         :param wait_for_completion: if the program should keep running until job finishes
-        :type wait_for_completion: bool
         :param check_interval: the time interval in seconds which the operator
             will check the status of any SageMaker job
-        :type check_interval: int
         :param max_ingestion_time: the maximum ingestion time in seconds. Any
             SageMaker jobs that run longer than this will fail. Setting this to
             None implies no timeout for any SageMaker job.
-        :type max_ingestion_time: int
         :return: A response to endpoint update
         """
         response = self.get_conn().update_endpoint(**config)
@@ -566,7 +529,6 @@ class SageMakerHook(AwsBaseHook):
         Return the training job info associated with the name
 
         :param name: the name of the training job
-        :type name: str
         :return: A dict contains all the training job info
         """
         return self.get_conn().describe_training_job(TrainingJobName=name)
@@ -637,7 +599,6 @@ class SageMakerHook(AwsBaseHook):
         Return the tuning job info associated with the name
 
         :param name: the name of the tuning job
-        :type name: str
         :return: A dict contains all the tuning job info
         """
         return self.get_conn().describe_hyper_parameter_tuning_job(HyperParameterTuningJobName=name)
@@ -647,7 +608,6 @@ class SageMakerHook(AwsBaseHook):
         Return the SageMaker model info associated with the name
 
         :param name: the name of the SageMaker model
-        :type name: str
         :return: A dict contains all the model info
         """
         return self.get_conn().describe_model(ModelName=name)
@@ -657,7 +617,6 @@ class SageMakerHook(AwsBaseHook):
         Return the transform job info associated with the name
 
         :param name: the name of the transform job
-        :type name: str
         :return: A dict contains all the transform job info
         """
         return self.get_conn().describe_transform_job(TransformJobName=name)
@@ -667,7 +626,6 @@ class SageMakerHook(AwsBaseHook):
         Return the processing job info associated with the name
 
         :param name: the name of the processing job
-        :type name: str
         :return: A dict contains all the processing job info
         """
         return self.get_conn().describe_processing_job(ProcessingJobName=name)
@@ -677,7 +635,6 @@ class SageMakerHook(AwsBaseHook):
         Return the endpoint config info associated with the name
 
         :param name: the name of the endpoint config
-        :type name: str
         :return: A dict contains all the endpoint config info
         """
         return self.get_conn().describe_endpoint_config(EndpointConfigName=name)
@@ -685,7 +642,6 @@ class SageMakerHook(AwsBaseHook):
     def describe_endpoint(self, name: str) -> dict:
         """
         :param name: the name of the endpoint
-        :type name: str
         :return: A dict contains all the endpoint info
         """
         return self.get_conn().describe_endpoint(EndpointName=name)
@@ -703,22 +659,16 @@ class SageMakerHook(AwsBaseHook):
         Check status of a SageMaker job
 
         :param job_name: name of the job to check status
-        :type job_name: str
         :param key: the key of the response dict
             that points to the state
-        :type key: str
         :param describe_function: the function used to retrieve the status
-        :type describe_function: python callable
         :param args: the arguments for the function
         :param check_interval: the time interval in seconds which the operator
             will check the status of any SageMaker job
-        :type check_interval: int
         :param max_ingestion_time: the maximum ingestion time in seconds. Any
             SageMaker jobs that run longer than this will fail. Setting this to
             None implies no timeout for any SageMaker job.
-        :type max_ingestion_time: int
         :param non_terminal_states: the set of nonterminal states
-        :type non_terminal_states: set
         :return: response of describe call after job is done
         """
         if not non_terminal_states:
@@ -769,20 +719,14 @@ class SageMakerHook(AwsBaseHook):
         job is complete.
 
         :param job_name: name of the training job to check status and display logs for
-        :type job_name: str
         :param non_terminal_states: the set of non_terminal states
-        :type non_terminal_states: set
         :param failed_states: the set of failed states
-        :type failed_states: set
         :param wait_for_completion: Whether to keep looking for new log entries
             until the job completes
-        :type wait_for_completion: bool
         :param check_interval: The interval in seconds between polling for new log entries and job completion
-        :type check_interval: int
         :param max_ingestion_time: the maximum ingestion time in seconds. Any
             SageMaker jobs that run longer than this will fail. Setting this to
             None implies no timeout for any SageMaker job.
-        :type max_ingestion_time: int
         :return: None
         """
         sec = 0
@@ -964,3 +908,14 @@ class SageMakerHook(AwsBaseHook):
             if e.response['Error']['Code'] in ['ValidationException', 'ResourceNotFound']:
                 return False
             raise
+
+    def delete_model(self, model_name: str):
+        """Delete SageMaker model
+
+        :param model_name: name of the model
+        """
+        try:
+            self.get_conn().delete_model(ModelName=model_name)
+        except Exception as general_error:
+            self.log.error("Failed to delete model, error: %s", general_error)
+            raise
