@@ -63,11 +63,9 @@ class SnsHook(AwsBaseHook):
         Publish a message to a topic or an endpoint.
 
         :param target_arn: either a TopicArn or an EndpointArn
-        :type target_arn: str
         :param message: the default message you want to send
         :param message: str
         :param subject: subject of message
-        :type subject: str
         :param message_attributes: additional attributes to publish for message filtering. This should be
             a flat dict; the DataType to be sent depends on the type of the value:
 
@@ -76,7 +74,6 @@ class SnsHook(AwsBaseHook):
             - int, float = Number
             - iterable = String.Array
 
-        :type message_attributes: dict
         """
         publish_kwargs: Dict[str, Union[str, dict]] = {
             'TargetArn': target_arn,
