@@ -35,31 +35,18 @@ class GlueJobOperator(BaseOperator):
     Language support: Python and Scala
 
     :param job_name: unique job name per AWS Account
-    :type job_name: Optional[str]
     :param script_location: location of ETL script. Must be a local or S3 path
-    :type script_location: Optional[str]
     :param job_desc: job description details
-    :type job_desc: Optional[str]
     :param concurrent_run_limit: The maximum number of concurrent runs allowed for a job
-    :type concurrent_run_limit: Optional[int]
     :param script_args: etl script arguments and AWS Glue arguments (templated)
-    :type script_args: dict
     :param retry_limit: The maximum number of times to retry this job if it fails
-    :type retry_limit: Optional[int]
     :param num_of_dpus: Number of AWS Glue DPUs to allocate to this Job.
-    :type num_of_dpus: int
     :param region_name: aws region name (example: us-east-1)
-    :type region_name: str
     :param s3_bucket: S3 bucket where logs and local etl script will be uploaded
-    :type s3_bucket: Optional[str]
     :param iam_role_name: AWS IAM Role for Glue Job Execution
-    :type iam_role_name: Optional[str]
     :param create_job_kwargs: Extra arguments for Glue Job Creation
-    :type create_job_kwargs: Optional[dict]
     :param run_job_kwargs: Extra arguments for Glue Job Run
-    :type run_job_kwargs: Optional[dict]
     :param wait_for_completion: Whether or not wait for job run completion. (default: True)
-    :type wait_for_completion: bool
     """
 
     template_fields: Sequence[str] = ('script_args',)
@@ -75,11 +62,11 @@ class GlueJobOperator(BaseOperator):
         *,
         job_name: str = 'aws_glue_default_job',
         job_desc: str = 'AWS Glue Job with Airflow',
-        script_location: Optional[str] = None,
+        script_location: str,
         concurrent_run_limit: Optional[int] = None,
         script_args: Optional[dict] = None,
-        retry_limit: Optional[int] = None,
-        num_of_dpus: int = 6,
+        retry_limit: int = 0,
+        num_of_dpus: Optional[int] = None,
         aws_conn_id: str = 'aws_default',
         region_name: Optional[str] = None,
         s3_bucket: Optional[str] = None,
@@ -113,7 +100,7 @@ class GlueJobOperator(BaseOperator):
 
         :return: the id of the current glue job.
         """
-        if self.script_location and not self.script_location.startswith(self.s3_protocol):
+        if not self.script_location.startswith(self.s3_protocol):
             s3_hook = S3Hook(aws_conn_id=self.aws_conn_id)
             script_name = os.path.basename(self.script_location)
             s3_hook.load_file(
