@@ -39,11 +39,8 @@ class GlueCrawlerOperator(BaseOperator):
     schema, format and data types of data stores within the AWS cloud.
 
     :param config: Configurations for the AWS Glue crawler
-    :type config: dict
     :param aws_conn_id: aws connection to use
-    :type aws_conn_id: Optional[str]
     :param poll_interval: Time (in seconds) to wait between two consecutive calls to check crawler status
-    :type poll_interval: Optional[int]
     """
 
     ui_color = '#ededed'
