@@ -37,15 +37,11 @@ class AthenaSensor(BaseSensorOperator):
     If the query fails, the task will fail.
 
     :param query_execution_id: query_execution_id to check the state of
-    :type query_execution_id: str
     :param max_retries: Number of times to poll for query state before
         returning the current state, defaults to None
-    :type max_retries: int
     :param aws_conn_id: aws connection to use, defaults to 'aws_default'
-    :type aws_conn_id: str
     :param sleep_time: Time in seconds to wait between two consecutive call to
         check query status on athena, defaults to 10
-    :type sleep_time: int
     """
 
     INTERMEDIATE_STATES = (
