@@ -42,14 +42,10 @@ class GlacierJobOperationSensor(BaseSensorOperator):
         :ref:`howto/operator:GlacierJobOperationSensor`
 
     :param aws_conn_id: The reference to the AWS connection details
-    :type aws_conn_id: str
     :param vault_name: name of Glacier vault on which job is executed
-    :type vault_name: str
     :param job_id: the job ID was returned by retrieve_inventory()
-    :type job_id: str
     :param poke_interval: Time in seconds that the job should wait in
         between each tries
-    :type poke_interval: float
     :param mode: How the sensor operates.
         Options are: ``{ poke | reschedule }``, default is ``poke``.
         When set to ``poke`` the sensor is taking up a worker slot for its
@@ -62,7 +58,6 @@ class GlacierJobOperationSensor(BaseSensorOperator):
         this mode if the time before the criteria is met is expected to be
         quite long. The poke interval should be more than one minute to
         prevent too much load on the scheduler.
-    :type mode: str
     """
 
     template_fields: Sequence[str] = ("vault_name", "job_id")
