@@ -33,18 +33,13 @@ class S3ToFTPOperator(BaseOperator):
 
     :param s3_bucket: The targeted s3 bucket. This is the S3 bucket from
         where the file is downloaded.
-    :type s3_bucket: str
     :param s3_key: The targeted s3 key. This is the specified file path for
         downloading the file from S3.
-    :type s3_key: str
     :param ftp_path: The ftp remote path. This is the specified file path for
         uploading file to the FTP server.
-    :type ftp_path: str
     :param aws_conn_id: reference to a specific AWS connection
-    :type aws_conn_id: str
     :param ftp_conn_id: The ftp connection id. The name or identifier for
         establishing a connection to the FTP server.
-    :type ftp_conn_id: str
     """
 
     template_fields: Sequence[str] = ('s3_bucket', 's3_key', 'ftp_path')
